@@ -5,6 +5,7 @@ from sklearn.neighbors import NearestNeighbors
 import matplotlib.pyplot as plt
 import pandas as pd
 from sklearn.linear_model import LogisticRegression
+from sklearn.preprocessing import StandardScaler
 import math
 import pandas.api.types as ptypes
 import seaborn as sns
@@ -89,6 +90,9 @@ class PsmPy:
                 joint_df = pd.concat([i, minority])
                 treatment = joint_df[self.treatment]
                 df_cleaned = joint_df.drop([self.treatment], axis=1)
+                # define standard scaler
+                scaler = StandardScaler()
+                df_cleaned = scaler.fit_transform(df_cleaned)
                 logistic = LogisticRegression(solver='liblinear')
                 logistic.fit(df_cleaned, treatment)
                 pscore = logistic.predict_proba(df_cleaned)[:, 1]
@@ -102,25 +106,28 @@ class PsmPy:
             if majority_len_diff != 0:
                 majority_leftover = majority[majority_trunc_len:]
                 len_major_leftover = len(majority_leftover)
-                if len_major_leftover <= 80:
-                    need_2_sample_more_majorclass = 80 - len_major_leftover
+                if len_major_leftover <= 20:
+                    need_2_sample_more_majorclass = 20 - len_major_leftover
                     # select the remaining ones from major class:
                     majority_leftover1 = majority[majority_trunc_len:]
                     # select the ones that have already been processed:
                     majority_already_folded = majority[:majority_trunc_len]
                     #self.majority_already_folded = majority_already_folded
-                    # sample from the ones already folded over above to get major class of 80 for last fold:
+                    # sample from the ones already folded over above to get major class of 20 for last fold:
                     majority_leftover2 = majority_already_folded.sample(
                         n=need_2_sample_more_majorclass)
-                    # add the leftover to the additional that need to be sampled to get to 40
+                    # add the leftover to the additional that need to be sampled to get to 20
                     majority_leftover_all = pd.concat(
                         [majority_leftover1, majority_leftover2])
-                    # sample a macthing 80 from the minor class
-                    minority_sample = minority.sample(n=80)
+                    # sample a macthing 20 from the minor class
+                    minority_sample = minority.sample(n=20)
                     joint_df = pd.concat(
                         [majority_leftover_all, minority_sample])
                     treatment = joint_df[self.treatment]
                     df_cleaned = joint_df.drop([self.treatment], axis=1)
+                    # define standard scaler
+                    scaler = StandardScaler()
+                    df_cleaned = scaler.fit_transform(df_cleaned)
                     logistic = LogisticRegression(solver='liblinear')
                     logistic.fit(df_cleaned, treatment)
                     pscore = logistic.predict_proba(df_cleaned)[:, 1]
@@ -134,6 +141,9 @@ class PsmPy:
                     joint_df = pd.concat([majority_extra, minority_sample])
                     treatment = joint_df[self.treatment]
                     df_cleaned = joint_df.drop([self.treatment], axis=1)
+                    # define standard scaler
+                    scaler = StandardScaler()
+                    df_cleaned = scaler.fit_transform(df_cleaned)
                     logistic = LogisticRegression(solver='liblinear')
                     logistic.fit(df_cleaned, treatment)
                     pscore = logistic.predict_proba(df_cleaned)[:, 1]
@@ -183,6 +193,9 @@ class PsmPy:
             joint_df = pd.concat([majority, minority])
             treatment = joint_df[self.treatment]
             df_cleaned = joint_df.drop([self.treatment], axis=1)
+            # define standard scaler
+            scaler = StandardScaler()
+            df_cleaned = scaler.fit_transform(df_cleaned)
             logistic = LogisticRegression(solver='liblinear')
             logistic.fit(df_cleaned, treatment)
             pscore = logistic.predict_proba(df_cleaned)[:, 1]
@@ -194,7 +207,7 @@ class PsmPy:
             # merge with treatment df
             treatment_dfonly = self.dataIDindx[[self.treatment]].reset_index()
             self.predicted_data = pd.merge(
-                predicted_data_reset, treatment_dfonly, how='inner', on='patient_ir_id')
+                predicted_data_reset, treatment_dfonly, how='inner', on=self.indx)
             predicted_data_control = self.predicted_data[self.predicted_data[self.treatment] == 0]
             predicted_data_treatment = self.predicted_data[self.predicted_data[self.treatment] == 1]
 
